require 'spec_helper'

describe Speedflow::Plugin::Git::Plugin do
  let(:plugin) do
    plugin = ::Speedflow::Plugin::Git::Plugin.new(double, double)
    plugin.client = double
    plugin
  end

  it '.action_create_branch' do
    allow(plugin.config)
      .to receive(:by_input)
      .with('branch')
      .and_return('')

    allow(plugin.prompt)
      .to receive(:ask_branch)
      .and_return('master')

    allow(plugin.prompt)
      .to receive(:ask)
      .with('What is the name of branch?', required: true)
      .and_return('master')

    allow(plugin.prompt)
      .to receive(:branch_type)
      .and_return(:remote)

    allow(plugin.client)
      .to receive(:branches)
      .with(:remote)
      .and_return(%w(master bar baz))

    allow(plugin.prompt)
      .to receive(:branch)
      .with(%w(master bar baz))
      .and_return('master')

    allow(plugin.config)
      .to receive(:by_input)
      .with('branch_from')
      .and_return('origin/master')

    allow(plugin.prompt)
      .to receive(:ok)
      .with("[GIT] Branch successful created: 'master' from 'origin/master'.")

    allow(plugin.client)
      .to receive(:create_branch)
      .with('master', 'origin/master')

    expected_hash = { 'branch' => 'master', 'branch_from' => 'origin/master' }
    expect(plugin.action_create_branch)
      .to eq expected_hash
  end

  it '.action_search_branch' do
    allow(plugin.prompt)
      .to receive(:branch_type)
      .and_return(:local)

    allow(plugin.client)
      .to receive(:branches)
      .with(:local)
      .and_return(%w(master foo bar :retry))

    allow(plugin.prompt)
      .to receive(:branch)
      .with(%w(foo bar :retry))
      .and_return(:retry)

    allow(plugin.prompt)
      .to receive(:branch_type)
      .and_return(:local)

    allow(plugin.client)
      .to receive(:branches)
      .with(:local)
      .and_return(%w(master foo bar :retry))

    allow(plugin.prompt)
      .to receive(:branch)
      .with(%w(master foo bar :retry))
      .and_return('master')

    expected_hash = { 'branch' => 'master' }
    expect(plugin.action_search_branch)
      .to eq expected_hash
  end
end
