require 'spec_helper'

describe Speedflow::Plugin::Git::Prompt do
  let(:prompt) do
    prompt = ::Speedflow::Plugin::Git::Prompt.new
    prompt.prompt = double
    prompt
  end
  let(:exception) do
    double(message: "Error\n")
  end

  it '.ok' do
    allow(prompt.prompt)
      .to receive(:ok)
      .with('Test')

    expect(prompt.ok('Test'))
  end

  it '.ask_branch' do
    allow(prompt.prompt)
      .to receive(:ask)
      .with('What is the name of branch?', required: true)
      .and_return('cool')

    expect(prompt.ask_branch)
      .to eq 'cool'
  end

  it '.branch' do
    allow(prompt.prompt)
      .to receive(:select)
      .with('Choose the branch:', required: true)
      .and_yield(double(choice: nil))
      .and_return 'master'

    branches = [
      double(name: 'master', remote: ''),
      double(name: 'HEAD -> origin/master', remote: 'origin')
    ]

    expect(prompt.branch(branches))
      .to eq 'master'

    # TODO: Complete specs with arrowed branches
  end

  it '.branch_type' do
    allow(prompt.prompt)
      .to receive(:select)
      .with('Choose the branch type:', required: true)
      .and_yield(double(choice: nil))
      .and_return :remote

    expect(prompt.branch_type)
      .to eq :remote
  end

  it '.errors' do
    allow(prompt.prompt)
      .to receive(:error).with('Git errors')
    allow(prompt.prompt)
      .to receive(:warn).with("Error\n")

    expect(prompt.errors(exception))
  end
end
